pub struct RequestedCertificateSet {
pub certifiers: Vec<String>,
pub types: HashMap<String, Vec<String>>,
}Expand description
A set of certificates being requested from a peer.
Matches the TS SDK’s RequestedCertificateSet wire format:
{ certifiers: string[], types: { [certTypeBase64]: string[] } }
Fields
certifiers: Vec<String>Certifier public keys whose certificates are accepted.
types: HashMap<String, Vec<String>>Maps certificate type (base64) to the list of field names to request.
Implementations
Sourceimpl RequestedCertificateSet
impl RequestedCertificateSet
Sourcepub fn keys(&self) -> impl Iterator<Item = &String>
pub fn keys(&self) -> impl Iterator<Item = &String>
Iterate over the requested certificate type keys.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Check if a certificate type is in the requested set.