ScriptChunk: a parsed element of a Bitcoin script.
Each chunk is either a bare opcode or a data push (opcode + data bytes).
Structs
- Script
Chunk - A single parsed element of a script.
ScriptChunk: a parsed element of a Bitcoin script.
Each chunk is either a bare opcode or a data push (opcode + data bytes).